summaryrefslogtreecommitdiffstats
path: root/docs/conf.py
diff options
context:
space:
mode:
Diffstat (limited to 'docs/conf.py')
-rw-r--r--docs/conf.py140
1 files changed, 90 insertions, 50 deletions
diff --git a/docs/conf.py b/docs/conf.py
index e4e1299e..0a20fda6 100644
--- a/docs/conf.py
+++ b/docs/conf.py
@@ -1,9 +1,10 @@
# -*- coding: utf-8 -*-
#
# Glances documentation build configuration file, created by
-# sphinx-quickstart on Tue Mar 25 19:57:21 2014.
+# sphinx-quickstart on Tue Mar 1 10:53:59 2016.
#
-# This file is execfile()d with the current directory set to its containing dir.
+# This file is execfile()d with the current directory set to its
+# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
@@ -11,45 +12,36 @@
# All configuration values have a default; values that are commented out
# serve to show the default.
-import datetime
+import sys
import os
+from datetime import datetime
# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#sys.path.insert(0, os.path.abspath('.'))
-cwd = os.path.realpath(os.path.dirname(__file__))
-project_path = os.path.realpath(os.path.join(cwd, '..', 'glances'))
-
-def get_version():
- init_file = os.path.realpath(os.path.join(project_path, '__init__.py'))
- f = open(init_file, 'r')
- try:
- for line in f:
- if line.startswith('__version__'):
- return line.strip().split(' = ')[1]
- else:
- raise ValueError("Version string not found")
- finally:
- f.close()
-
-_version = get_version()
-_year = datetime.datetime.now().year
-_copyright = u'{0}, Nicolas Hennion'.format(_year)
-
-# -- General configuration -----------------------------------------------------
+
+# Insert Glances' path into the system.
+sys.path.insert(0, os.path.abspath('..'))
+
+from glances import __version__
+
+# -- General configuration ------------------------------------------------
# If your documentation needs a minimal Sphinx version, state it here.
#needs_sphinx = '1.0'
-# Add any Sphinx extension module names here, as strings. They can be extensions
-# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
+# Add any Sphinx extension module names here, as strings. They can be
+# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
+# ones.
extensions = []
# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']
-# The suffix of source filenames.
+# The suffix(es) of source filenames.
+# You can specify multiple suffix as a list of string:
+# source_suffix = ['.rst', '.md']
source_suffix = '.rst'
# The encoding of source files.
@@ -59,20 +51,25 @@ source_suffix = '.rst'
master_doc = 'index'
# General information about the project.
-project = u'Glances'
-copyright = _copyright
+project = 'Glances'
+author = 'Nicolas Hennion'
+year = datetime.now().year
+copyright = '%d, %s' % (year, author)
# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
-version = _version
+version = __version__
# The full version, including alpha/beta/rc tags.
release = version
# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
+#
+# This is also used if you do content translation via gettext catalogs.
+# Usually you set "language" from the command line for these cases.
#language = None
# There are two options for replacing |today|: either, you set today to some
@@ -85,7 +82,8 @@ release = version
# directories to ignore when looking for source files.
exclude_patterns = ['_build']
-# The reST default role (used for this markup: `text`) to use for all documents.
+# The reST default role (used for this markup: `text`) to use for all
+# documents.
#default_role = None
# If true, '()' will be appended to :func: etc. cross-reference text.
@@ -105,17 +103,27 @@ pygments_style = 'sphinx'
# A list of ignored prefixes for module index sorting.
#modindex_common_prefix = []
+# If true, keep warnings as "system message" paragraphs in the built documents.
+#keep_warnings = False
-# -- Options for HTML output ---------------------------------------------------
+# If true, `todo` and `todoList` produce output, else they produce nothing.
+todo_include_todos = False
+
+
+# -- Options for HTML output ----------------------------------------------
# The theme to use for HTML and HTML Help pages. See the documentation for
# a list of builtin themes.
-html_theme = 'default'
+html_theme = 'alabaster'
# Theme options are theme-specific and customize the look and feel of a theme
# further. For a list of options available for each theme, see the
# documentation.
-#html_theme_options = {}
+html_theme_options = {
+ 'github_user': 'nicolargo',
+ 'github_repo': 'glances',
+ 'show_powered_by': False
+}
# Add any paths that contain custom themes here, relative to this directory.
#html_theme_path = []
@@ -131,15 +139,20 @@ html_theme = 'default'
# of the sidebar.
#html_logo = None
-# The name of an image file (within the static path) to use as favicon of the
-# docs. This file should be a Windows icon file (.ico) being 16x16 or 32x32
+# The name of an image file (relative to this directory) to use as a favicon of
+# the docs. This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
#html_favicon = None
# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
-#html_static_path = ['_static']
+html_static_path = ['_static']
+
+# Add any extra paths that contain custom files (such as robots.txt or
+# .htaccess) here, relative to this directory. These files are copied
+# directly to the root of the documentation.
+#html_extra_path = []
# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
# using the given strftime format.
@@ -150,7 +163,14 @@ html_theme = 'default'
#html_use_smartypants = True
# Custom sidebar templates, maps document names to template names.
-#html_sidebars = {}
+html_sidebars = {
+ '**': [
+ 'about.html',
+ 'navigation.html',
+ 'links.html',
+ 'searchbox.html'
+ ]
+}
# Additional templates that should be rendered to pages, maps page names to
# template names.
@@ -166,7 +186,7 @@ html_theme = 'default'
#html_split_index = False
# If true, links to the reST sources are added to the pages.
-#html_show_sourcelink = True
+html_show_sourcelink = False
# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
#html_show_sphinx = True
@@ -182,11 +202,24 @@ html_theme = 'default'
# This is the file name suffix for HTML files (e.g. ".xhtml").
#html_file_suffix = None
+# Language to be used for generating the HTML full-text search index.
+# Sphinx supports the following languages:
+# 'da', 'de', 'en', 'es', 'fi', 'fr', 'h', 'it', 'ja'
+# 'nl', 'no', 'pt', 'ro', 'r', 'sv', 'tr'
+#html_search_language = 'en'
+
+# A dictionary with options for the search language support, empty by default.
+# Now only 'ja' uses this config value
+#html_search_options = {'type': 'default'}
+
+# The name of a javascript file (relative to the configuration directory) that
+# implements a search results scorer. If empty, the default will be used.
+#html_search_scorer = 'scorer.js'
+
# Output file base name for HTML help builder.
htmlhelp_basename = 'Glancesdoc'
-
-# -- Options for LaTeX output --------------------------------------------------
+# -- Options for LaTeX output ---------------------------------------------
latex_elements = {
# The paper size ('letterpaper' or 'a4paper').
@@ -197,13 +230,17 @@ latex_elements = {
# Additional stuff for the LaTeX preamble.
#'preamble': '',
+
+# Latex figure (float) alignment
+#'figure_align': 'htbp',
}
# Grouping the document tree into LaTeX files. List of tuples
-# (source start file, target name, title, author, documentclass [howto/manual]).
+# (source start file, target name, title,
+# author, documentclass [howto, manual, or own class]).
latex_documents = [
- ('index', 'Glances.tex', u'Glances Documentation',
- u'Nicolas Hennion', 'manual'),
+ (master_doc, 'Glances.tex', 'Glances Documentation',
+ 'Nicolas Hennion', 'manual'),
]
# The name of an image file (relative to this directory) to place at the top of
@@ -227,28 +264,28 @@ latex_documents = [
#latex_domain_indices = True
-# -- Options for manual page output --------------------------------------------
+# -- Options for manual page output ---------------------------------------
# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
- ('index', 'glances', u'Glances Documentation',
- [u'Nicolas Hennion'], 1)
+ ('glances', 'glances', 'An eye on your system',
+ '', 1)
]
# If true, show URL addresses after external links.
#man_show_urls = False
-# -- Options for Texinfo output ------------------------------------------------
+# -- Options for Texinfo output -------------------------------------------
# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
# dir menu entry, description, category)
texinfo_documents = [
- ('index', 'Glances', u'Glances Documentation',
- u'Nicolas Hennion', 'Glances', 'One line description of project.',
- 'Miscellaneous'),
+ (master_doc, 'Glances', 'Glances Documentation',
+ author, 'Glances', 'One line description of project.',
+ 'Miscellaneous'),
]
# Documents to append as an appendix to all manuals.
@@ -259,3 +296,6 @@ texinfo_documents = [
# How to display URL addresses: 'footnote', 'no', or 'inline'.
#texinfo_show_urls = 'footnote'
+
+# If true, do not generate a @detailmenu in the "Top" node's menu.
+#texinfo_no_detailmenu = False